Provides the equation for a coupled oscillator model for the differential equation solver (ode) to plot
cloCoupledOde(t, state, parameters)A parameter used by the ode and passed by functions calling cloCoupleOde
Another parameter used by the ode and passed by functions calling cloCoupleOde
Another parameter used by the ode and passed by functions calling cloCoupleOde
A list with the rates of change for each state variable.